@@ -1690,6 +1690,13 @@ def cli(
                         d_1000 = 0
                         d_2000 = 0
                         d_3000 = 0
+                        d_4000 = 0
+                        d_5000 = 0
+                        d_6000 = 0
+                        d_7000 = 0
+                        d_8000 = 0
+                        d_9000 = 0
+                        d_10000 = 0
 
                         for account, distance in user_df.itertuples(index=False):
                             account = int(account)
@@ -1706,6 +1713,20 @@ def cli(
                                 d_2000 += 1
                             elif distance == 3000:
                                 d_3000 += 1
+                            elif distance == 4000:
+                                d_4000 += 1
+                            elif distance == 5000:
+                                d_5000 += 1
+                            elif distance == 6000:
+                                d_6000 += 1
+                            elif distance == 7000:
+                                d_7000 += 1
+                            elif distance == 8000:
+                                d_8000 += 1
+                            elif distance == 9000:
+                                d_9000 += 1
+                            elif distance == 10000:
+                                d_10000 += 1
 
                         with open(
                             save_file, "w+", encoding="utf-8"
@@ -1719,6 +1740,13 @@ def cli(
                         color_print_green("  ├  Users within 1000m: ", str(d_1000))
                         color_print_green("  ├  Users within 2000m: ", str(d_2000))
                         color_print_green("  ├  Users within 3000m: ", str(d_3000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_4000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_5000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_6000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_7000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_8000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_9000))
+                        color_print_green("  ├  Users within 3000m: ", str(d_10000))
                         color_print_green("  ├  Total users found:  ", str(total))
                         color_print_green("  └  Location list saved to: ", save_file)
 
